@@ -24,6 +24,31 @@ Concept Unique Identifier (CUI) or a term from the Unified
 Medical Language System (UMLS)
 
 =head2 Optional Arguments:
+
+=head3 --config FILE
+
+This is the configuration file. The format of the configuration 
+file is as follows:
+
+SAB :: <include|exclude> <source1, source2, ... sourceN>
+
+REL :: <include|exclude> <relation1, relation2, ... relationN>
+
+For example, if we wanted to use the MSH vocabulary with only 
+the RB/RN relations, the configuration file would be:
+
+SAB :: include MSH
+REL :: include RB, RN
+
+or 
+
+SAB :: include MSH
+REL :: exclude PAR, CHD
+
+If you go to the configuration file directory, there will 
+be example configuration files for the different runs that 
+you have performed.
+
 =head3 --debug
 
 This sets the debug flag for testing
@@ -394,7 +419,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: findCuiDepth.pl,v 1.4 2010/03/23 21:41:11 btmcinnes Exp $';
+    print '$Id: findCuiDepth.pl,v 1.5 2010/03/31 19:38:00 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
